@@ -1,8 +1,4 @@
-from blockapi.services import (
-    BlockchainAPI,
-    APIKeyMissing,
-    on_failure_return_none
-)
+from blockapi.services import (APIKeyMissing, BlockchainAPI)
 
 
 class CryptoIDAPI(BlockchainAPI):
@@ -17,13 +13,14 @@ class CryptoIDAPI(BlockchainAPI):
     symbol = None
     base_url = 'http://chainz.cryptoid.info'
     rate_limit = 0
-    coef = 1e-8
+    coef = 1
     max_items_per_page = None
     page_offset_step = None
     confirmed_num = None
 
     supported_requests = {
-        'get_balance': '/{symbol}/api.dws?q=getbalance&a={address}&key={api_key}',
+        'get_balance': '/{symbol}/api.dws?q=getbalance&a={address}'
+                       '&key={api_key}',
     }
 
     def __init__(self, address, api_key=None):
@@ -32,14 +29,16 @@ class CryptoIDAPI(BlockchainAPI):
 
         super().__init__(address, api_key)
 
-    @on_failure_return_none()
     def get_balance(self):
         response = self.request('get_balance',
                                 api_key=self.api_key,
                                 symbol=self.symbol.lower(),
                                 address=self.address)
 
-        return [{'symbol': self.symbol, 'amount': response * self.coef}]
+        return [{
+            'symbol': self.symbol,
+            'amount': float(response) * self.coef
+        }]
 
 
 class CryptoIDLitecoinAPI(CryptoIDAPI):
@@ -48,9 +47,7 @@ class CryptoIDLitecoinAPI(CryptoIDAPI):
 
 class CryptoIDDashAPI(CryptoIDAPI):
     symbol = 'DASH'
-    coef = 1
 
 
 class CryptoIDGroestlcoinAPI(CryptoIDAPI):
     symbol = 'GRS'
-    coef = 1
