@@ -1,23 +1,19 @@
 import dateutil.parser
 
-from blockapi.services import (
-    BlockchainAPI,
-    set_default_args_values,
-    APIError,
-    on_failure_return_none
-)
+from blockapi.services import (APIError, BlockchainAPI,
+                               set_default_args_values)
 
 
 class TzscanAPI(BlockchainAPI):
     """
     Tezos
     API docs: https://tzscan.io/api
-    Explorer: https://tzscan.io
-
-    Second API
-    https://api.tzstats.com/explorer/
+        Explorer: https://tzscan.io
     """
 
+    # inaccurate results for balances, use on your own risk
+    active = False
+
     symbol = 'XTZ'
     base_url = None  # endpoint is created in runtime
     rate_limit = 0
@@ -35,22 +31,22 @@ class TzscanAPI(BlockchainAPI):
                              '?cycle={cycle}&number=50&p={page}',
         'get_bakings': '/v3/cycle_bakings/{address}'
                        '?p={page_offset}&number={number}',
-        'get_bakings_tzstats': 'account/{address}',
         'get_endorsements': '/v3/cycle_endorsements/{address}'
                             '?p={page_offset}&number={number}'
     }
 
-    def __init__(self, address, api_key=None):
+    def __init__(self, address, *args, **kwargs):
         super().__init__(address)
         # this API is very unstable, add some functionality to prevent fails
         self._base_url_temp = 'https://api{num}.dunscan.io'  # num is 1-6
         self._api_nums = [1, 2, 3, 4, 5, 6]
 
-    @on_failure_return_none()
     def get_balance(self):
         balance = self._safe_request('get_balance', address=self.address)
-        return [{'symbol': self.symbol,
-                 'amount': float(balance['spendable']) * self.coef}]
+        return [{
+            'symbol': self.symbol,
+            'amount': float(balance['spendable']) * self.coef
+        }]
 
     def get_rewards(self, offset=0, limit=50):
         rewards = self._safe_request('get_rewards', address=self.address,
@@ -263,17 +259,6 @@ class TzscanAPI(BlockchainAPI):
             'priority': float(e['priority'])
         }
 
-    @set_default_args_values
-    def get_bakings_tzstats(self, offset=None, limit=None):
-        self._base_url_temp = 'https://api.tzstats.com/explorer/'
-        response = self._safe_request(
-            'get_bakings_tzstats',
-            address=self.address,
-            page_offset=offset,
-            number=limit
-        )
-        return response
-
     @set_default_args_values
     def get_bakings(self, offset=None, limit=None):
         baks = self._safe_request(
