@@ -1,7 +1,4 @@
-from blockapi.services import (
-    BlockchainAPI,
-    on_failure_return_none
-)
+from blockapi.services import BlockchainAPI
 
 
 class ZensystemAPI(BlockchainAPI):
@@ -25,7 +22,6 @@ class ZensystemAPI(BlockchainAPI):
         'get_balance': '/addr/{address}',
     }
 
-    @on_failure_return_none()
     def get_balance(self):
         response = self.request('get_balance',
                                 address=self.address)
