@@ -1,7 +1,7 @@
 from pytest import mark
 
 from blockapi.api.tzscan import TzscanAPI
-from blockapi.test_init import test_addresses
+from blockapi.test_data import test_addresses
 
 
 class TestTzscanAPI:
@@ -18,7 +18,7 @@ class TestTzscanAPI:
         api = TzscanAPI(address=self.ADDRESS)
         result = api.get_balance()
 
-        assert result == [{'symbol': 'XTZ', 'amount': 2068856.4582429999}]
+        assert result == [{'symbol': 'XTZ', 'amount': 1221639.05003}]
 
     @mark.vcr()
     def test_get_rewards(self):
@@ -36,17 +36,6 @@ class TestTzscanAPI:
         assert isinstance(result, list)
         assert len(result) == 3
 
-    @mark.vcr()
-    def test_get_bakings_tzstats(self):
-        api = TzscanAPI(address=self.REWARD_ADDRESS)
-        result = api.get_bakings_tzstats()
-
-        assert result["address"] == self.REWARD_ADDRESS
-        assert "manager" in result
-        assert "delegate" in result
-        assert "manager_account" in result
-        assert "delegate_account" in result
-
     @mark.vcr()
     def test_get_endorsements(self):
         api = TzscanAPI(address=self.ADDRESS)
