@@ -4,7 +4,7 @@ from typing import Union
 from dateutil.parser import parse as parse_date
 
 
-def parse_dt(dt: Union[int, str]) -> datetime:
+def parse_dt(dt: Union[str, int, float]) -> datetime:
     """
     Convert datetime from string or timestamp into `datetime.datetime`
     """
@@ -12,5 +12,7 @@ def parse_dt(dt: Union[int, str]) -> datetime:
         return parse_date(dt)
     elif isinstance(dt, int):
         return datetime.fromtimestamp(dt)
+    elif isinstance(dt, float):
+        return datetime.fromtimestamp(dt)
     else:
         raise TypeError(f'Type {type(dt)} is not supported.')
