@@ -1,5 +1,9 @@
 from decimal import Decimal, InvalidOperation
-from typing import Union
+from numbers import Number
+from typing import Union, Optional
+
+
+SupportsNumber = Union[str, Number]
 
 
 def to_int(number: Union[int, str]):
@@ -37,6 +41,18 @@ def raw_to_decimals(
     return remove_exponent(res)
 
 
+def decimals_to_raw(
+    amount: Union[int, str], decimals: Union[int, str]
+) -> Decimal:
+    """
+    Convert decimal value to raw format
+    """
+    amount_ = to_decimal(amount)
+    decimals_ = to_decimal(decimals)
+    res = amount_ * pow(10, decimals_)
+    return remove_exponent(res)
+
+
 def remove_exponent(d: Decimal) -> Decimal:
     """
     https://docs.python.org/3/library/decimal.html#decimal-faq
@@ -47,3 +63,18 @@ def remove_exponent(d: Decimal) -> Decimal:
         return d.quantize(Decimal(1)) if d == d.to_integral() else d.normalize()
     except InvalidOperation:
         return d
+
+
+def safe_opt_decimal(obj: Optional[SupportsNumber]) -> Decimal:
+    """
+    This function is primarily for parsing 3rd party APIs that sometimes,
+    despite stating in their docs that *number* is returned, may return null.
+
+    >>> safe_opt_decimal(None)
+    Decimal('0')
+    """
+    if obj is None:
+        return Decimal('0')
+    else:
+        return to_decimal(obj)
+
